<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Response;
use Illuminate\Http\Request;

class AuthenticationController extends Controller
{
    /**
     * @unauthenticated
     * 
     * @return "{'status': 'success','token': 'plaintexttoken'}"
     * 
     * 
     */
    public function authorize(Request $request) {
        $request->validate([
            'email'  => 'required|email',
            'password'    => 'required|string'
        ]);
        
        if (!$request->has('email') || !$request->has('password')) {
            return json_encode([
                'status' => 'invalid',
                'message' => 'ingen brukernavn eller passord oppgitt'
            ], 422);
        }

        $credentials = $request->only('email', 'password');

        if (Auth::attempt($credentials)) {
            $user = Auth::user();
            $token = $user->createToken($request->token_name ?? 'default');
            return json_encode([
                'status' => 'success',
                'token' => $token->plainTextToken
            ], Response::HTTP_ACCEPTED);
        }

        return json_encode([
            'status' => 'invalid',
            'message' => 'ugyldig bruker/passord'
        ], Response::HTTP_UNAUTHORIZED);

    }
}
